# ink_extensions
Python dependencies for running [Inkscape](https://inkscape.org) extensions outside of Inkscape

----

These files were initially forked from Inkscape 0.91, and modified slightly to allow operation under both python 2.x and 3.x.

License: GPL v2.
